##
##  gotty.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2020 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package version
%define       V_gotty_base 2.0.0a3
%define       V_gotty_snap 20200607

#   package information
Name:         gotty
Summary:      Web Terminal Sharing
URL:          https://github.com/yudai/gotty
Vendor:       Iwasaki Yudai
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        EVAL
Group:        Web
License:      MIT
Version:      %{V_gotty_base}.%{V_gotty_snap}
Release:      20200607

#   list of sources
Source0:      http://download.openpkg.org/components/versioned/gotty/gotty-%{V_gotty_snap}.tar.xz
Source1:      rc.gotty
Source2:      gotty-ssh.sh

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101, go
PreReq:       OpenPKG, openpkg >= 20160101

%description
    GoTTY is a simple command line tool that turns any CLI tool into a
    web application.

%track
    prog gotty:release = {
        version   = %{V_gotty_base}
        url       = https://github.com/yudai/gotty/releases
        regex     = v(__VER__)\.tar\.gz
    }
    prog gotty:snapshot = {
        version   = %{V_gotty_snap}
        url       = http://download.openpkg.org/components/versioned/gotty/
        regex     = gotty-(__VER__)\.tar\.xz
    }

%prep
    %setup -q -n gotty

%build
    #   build program
    export GOPATH=`pwd`
    cd src/github.com/yudai/gotty
    go build -v .

%install
    #   create directory hierarchy
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/bin \
        $RPM_BUILD_ROOT%{l_prefix}/sbin \
        $RPM_BUILD_ROOT%{l_prefix}/etc/rc.d \
        $RPM_BUILD_ROOT%{l_prefix}/var/gotty/log \
        $RPM_BUILD_ROOT%{l_prefix}/var/gotty/run

    #   install program
    %{l_shtool} install -c -s -m 755 \
        src/github.com/yudai/gotty/gotty \
        $RPM_BUILD_ROOT%{l_prefix}/bin/gotty

    #   install helper tools
    %{l_shtool} install -c -m 755 %{l_value -s -a} \
        -e 's;@l_bash@;%{l_bash};g' \
        %{SOURCE gotty-ssh.sh} \
        $RPM_BUILD_ROOT%{l_prefix}/bin/gotty-ssh

    #   install run-command script
    %{l_shtool} install -c -m 755 %{l_value -s -a} \
        %{SOURCE rc.gotty} $RPM_BUILD_ROOT%{l_prefix}/etc/rc.d/

    #   determine installation files
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT \
        %{l_files_std} \
        '%attr(-,%{l_rusr},%{l_rgrp}) %{l_prefix}/var/gotty/*'

%files -f files

%clean

%post
    if [ $1 -eq 1 ]; then
        :
    elif [ $1 -eq 2 ]; then
        #   after upgrade, restart service
        eval `%{l_rc} gotty status 2>/dev/null`
        [ ".$gotty_active" = .yes ] && %{l_rc} gotty restart
    fi
    exit 0

%preun
    #   before erase, stop service and remove log files
    if [ $1 -eq 0 ]; then
        %{l_rc} gotty stop 2>/dev/null
        rm -f  $RPM_INSTALL_PREFIX/var/gotty/log/* >/dev/null 2>&1 || true
        rm -f  $RPM_INSTALL_PREFIX/var/gotty/run/* >/dev/null 2>&1 || true
    fi
    exit 0

